network\_wrangler.ProjectCard
=============================

.. currentmodule:: network_wrangler

.. autoclass:: ProjectCard

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ProjectCard.__init__
      ~ProjectCard.build_link_selection_query
      ~ProjectCard.new_roadway
      ~ProjectCard.new_transit_right_of_way
      ~ProjectCard.parallel_managed_lanes
      ~ProjectCard.read
      ~ProjectCard.roadway_attribute_change
      ~ProjectCard.transit_attribute_change
      ~ProjectCard.validate_project_card_schema
      ~ProjectCard.write
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ProjectCard.ROADWAY_CATEGORIES
      ~ProjectCard.SECONDARY_TRANSIT_CATEGORIES
      ~ProjectCard.TRANSIT_CATEGORIES
      ~ProjectCard.UNSPECIFIED_PROJECT_NAMES
   
   